@@ -36,10 +36,6 @@
 #ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #else
-#	include <io.h>
-#	include <sys/stat.h>
-#	include <sys/types.h>
-/*
 #	define S_IRUSR 0000400
 #	define S_IWUSR 0000200
 #	define S_IRGRP 0000040
@@ -47,7 +43,6 @@
 #	define _S_ISREG(m) (((m)&0170000) == 0100000)
 #	define S_ISREG(m) _S_ISREG(m)
 #	define O_NONBLOCK 0x4000
-*/
 #endif
 
 #ifndef PROT_READ
@@ -63,6 +58,11 @@
 #	define MAP_FAILED ((void *)-1)
 #endif
 
+#if !defined(MAP_SHARED) || !defined(HAVE_MMAP)
+/* Only define this where mmap() is not supported */
+#	define MAP_SHARED 0
+#endif
+
 /* Implementational detail - not for global header */
 #define OLE_DEBUG 0
 
@@ -333,7 +333,7 @@ write_cache_block (MsOle *f, BBBlkAttr *attr)
 		g_warning ("Fatal error writing block %d at %d\n", attr->blk, offset);
 #if OLE_DEBUG > 0
 	g_print ("Writing cache block %d to offset %d\n",
-		attr->blk, offset);
+		 attr->blk, offset);
 #endif	
 	attr->dirty = FALSE;
 }
@@ -1354,7 +1354,7 @@ read_sb (MsOle *f)
 		if (ptr == UNUSED_BLOCK ||
 		    ptr == SPECIAL_BLOCK) {
 			g_warning ("Corrupt small block file: serious error, "
-				 "invalid block in chain\n");
+				   "invalid block in chain\n");
 			g_array_free (f->sbf, TRUE);
 			f->sbf = 0;
 			return 0;
@@ -1399,7 +1399,7 @@ read_sb (MsOle *f)
 	
 	if (f->sbf->len * BB_BLOCK_SIZE < f->sb->len*SB_BLOCK_SIZE) {
 		g_warning ("Not enough small block file for descriptors\n"
-			 "sbf->len == %d, sb->len == %d\n", f->sbf->len,
+			   "sbf->len == %d, sb->len == %d\n", f->sbf->len,
 			f->sb->len);
 		return 0;
 	}
@@ -1579,9 +1579,7 @@ ms_ole_open_vfs (MsOle **fs, const char *name,
 		 gboolean try_mmap,
 		 MsOleSysWrappers *wrappers)
 {
-#ifdef HAVE_MMAP   
 	int prot = PROT_READ | PROT_WRITE;
-#endif /* HAVE_MMAP */
 	MsOle *f;
 	int file;
 
@@ -1602,9 +1600,7 @@ ms_ole_open_vfs (MsOle **fs, const char *name,
 	if (file == -1) {
 		f->file_des = file = f->syswrap->open2 (name, O_RDONLY);
 		f->mode = 'r';
-#ifdef HAVE_MMAP
 		prot &= ~PROT_WRITE;
-#endif /* HAVE_MMAP */
 	}
 
 	if ((file == -1) || !(f->syswrap->isregfile (file))) {
@@ -1739,7 +1735,7 @@ ms_ole_create_vfs (MsOle **fs, const char *name, gboolean try_mmap,
 		    SEEK_SET) == (off_t)-1) ||
 	    (f->syswrap->write (file, &zero, 1) == -1)) {
 		g_warning ("Serious error extending file to %d bytes\n",
-			 BB_BLOCK_SIZE*init_blocks);
+			   BB_BLOCK_SIZE*init_blocks);
 		g_free (f);
 		*fs = NULL;
 		return MS_OLE_ERR_SPACE;
@@ -1834,9 +1830,6 @@ destroy_pps (GList *l)
 	if (!l)
 		return;
 
-	if (!l)
-	  return;
-
 	for (tmp = l; tmp; tmp = g_list_next (tmp)) {
 		PPS *pps = tmp->data;
 		if (pps->name) {
@@ -2022,7 +2015,7 @@ free_allocation (MsOle *f, guint32 startblock, gboolean is_big_block_stream)
 			} else if (p == SPECIAL_BLOCK ||
 				   p == UNUSED_BLOCK) {
 				g_warning ("Serious bug: Special / Unused block "
-					 "in BB allocation\n");
+					   "in BB allocation\n");
 				return;
 			}
 			g_array_index (f->bb, BLP, p) = UNUSED_BLOCK;
@@ -2040,7 +2033,7 @@ free_allocation (MsOle *f, guint32 startblock, gboolean is_big_block_stream)
 			} else if (p == SPECIAL_BLOCK ||
 				   p == UNUSED_BLOCK) {
 				g_warning ("Serious bug: Special / Unused block "
-					 "in SB allocation\n");
+					   "in SB allocation\n");
 				return;
 			}
 			g_array_index (f->sb, BLP, p) = UNUSED_BLOCK;
